@@ -20,8 +20,9 @@ logging.basicConfig(format='%(levelname)s:%(message)s', level=logging.INFO)
 # Create a temporary directory to hold all the writable parts of the configuration + any
 # data stored in the databases. We put this in a special user directory so that all the files
 # are self-conained
-tmpdir = os.makedirs(os.getcwd() + "/tmp/", exist_ok=True)
-dbdir = tempfile.TemporaryDirectory(prefix=os.getcwd() + "/tmp/")
+tmpdir = os.makedirs(os.getcwd() + "/scratch/tmp/", exist_ok=True)
+# make sure this exists in the 'scratch' directory
+dbdir = tempfile.TemporaryDirectory(prefix=os.getcwd() + "/scratch/tmp/")
 
 class Service:
     singularity_container: str
@@ -42,18 +43,22 @@ class Service:
     def run(cls):
         raise NotImplementedError
 
+    @classmethod
+    def stop(cls, instance):
+        client.instance.Instance.stop(f"instance://{instance.name}")
+
 
 class MongoDB(Service):
     singularity_container = "docker://mongo:latest"
     docker_container = ("mongo", "latest")
 
     @classmethod
-    def run(cls, image_file: str = "mongo:latest.sif"):
+    def run(cls, image_file: str = "/sw/apps/singularity-images/mines_data_engineering/mongo.sif"):
         cls.pull(image_file)
         if USE_DOCKER:
             return client.containers.run(cls.docker_container[0], detach=True, auto_remove=False, name="data-engineering-mongodb")
         else:
-            inst = client.instance.instance(image=image_file, options=[f"-B {dbdir.name}:/data/db", f"-B {dbdir.name}:/tmp"])
+            inst = client.instance.instance(image=image_file, options=[f"-B {dbdir.name}:/data/db", f"-B {dbdir.name}:/tmp"], name='data-engineering-mongodb')
             def _run_mongo():
                 client.execute(image=f"instance://{inst.name}", command=["mongod"])
             t = threading.Thread(target=_run_mongo)
@@ -66,13 +71,13 @@ class TimescaleDB(Service):
     docker_container = ("timescale/timescaledb", "latest-pg14")
 
     @classmethod
-    def run(cls, image_file: str = "timescaledb:latest-pg14.sif"):
+    def run(cls, image_file: str = "/sw/apps/singularity-images/mines_data_engineering/timescaledb-pg14.sif"):
         cls.pull(image_file)
         if USE_DOCKER:
             return client.containers.run(cls.docker_container[0], detach=True, auto_remove=False, name="data-engineering-timescaledb")
         else:
             os.environ["POSTGRES_PASSWORD"] = "password"
-            inst = client.instance.instance(image=image_file, options=[f"-B {dbdir.name}:/var/lib/postgresql/data", f"-B {dbdir.name}:/var/run/postgresql", f"--env=POSTGRES_PASSWORD"])
+            inst = client.instance.instance(image=image_file, options=[f"-B {dbdir.name}:/var/lib/postgresql/data", f"-B {dbdir.name}:/var/run/postgresql", f"--env=POSTGRES_PASSWORD"], name='data-engineering-timescaledb')
             def _run_timescale():
                 client.execute(image=f"instance://{inst.name}", command=["/usr/local/bin/docker-entrypoint.sh", "postgres"])
             t = threading.Thread(target=_run_timescale)
